<?php
error_reporting (E_ALL);
require_once '../phpoot.php';
$tmpl = new phpoot;
$tmpl->setErrorHandling(PEAR_ERROR_PRINT);
$tmpl->setTemplateFile('./attribute.html');
$model_data = array(
  'table' => array(
    array( 
		'name' 	  => 'PHP',
		'url'     => 'http://www.php.net/',
		'webpage' => 'PHP: Hypertext Preprocessor'
	),
	array( 
		'name' 	  => 'Ruby',
		'url'     => 'http://www.ruby-lang.org/',
		'webpage' => 'Ruby Home Page'
	),
	array( 
		'name' 	  => 'python',
		'url'     => 'http://www.python.org/',
		'webpage' => 'Python Language Website'
	)
  )
);
$tmpl->display($model_data);
?>